package cn.youle.pet.shop.controller;

import cn.youle.pet.shop.common.JsonResponse;
import cn.youle.pet.shop.enums.ENUM_HTTP_CONTENT_TYPE;
import cn.youle.pet.shop.exception.PetShopException;
import cn.youle.pet.shop.pojo.dto.UploadDTO;
import cn.youle.pet.shop.service.ICommonService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.InputStreamResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;

/**
 * @projectName: pet-shop
 * @description:
 * @author: Administrator
 * @createTime: 2023/9/20 9:04
 */
@RestController
@RequestMapping("/common")
public class CommonController {

    @Autowired
    private ICommonService commonService;

    /**
     * 上传文件
     *
     * @param file
     * @return
     */
    @PostMapping("/upload")
    public JsonResponse upload(@RequestParam("file") MultipartFile file) {
        String upload = commonService.upload(file);
        return JsonResponse.ok(upload);
    }

    /**
     * 下载文件
     *
     * @param filePath
     * @return
     */
    @GetMapping("/download")
    public ResponseEntity<InputStreamResource> download(@RequestParam("filePath") String filePath) {
        if(filePath == null){
            return null;
        }
        String suffix = filePath.substring(filePath.lastIndexOf("."));
        ENUM_HTTP_CONTENT_TYPE enumHttpContentType = ENUM_HTTP_CONTENT_TYPE.matchFileType(suffix);
        if(enumHttpContentType == null){
            return null;
        }
        MediaType mediaType = enumHttpContentType.getMediaType();
        HttpHeaders httpHeaders = new HttpHeaders();
        httpHeaders.setContentType(mediaType);
        httpHeaders.add("Accept","*/*");
        try {
            return new ResponseEntity(
                    commonService.download(filePath),
                    httpHeaders,
                    HttpStatus.OK
            );
        }catch (Exception e){
            return new ResponseEntity<>(null,httpHeaders,HttpStatus.OK);
        }
    }
}
