package cn.youle.pet.shop.controller;


import cn.youle.pet.shop.common.JsonResponse;
import cn.youle.pet.shop.pojo.dto.product.ProductDetailDTO;
import cn.youle.pet.shop.pojo.dto.product.ProductListDTO;
import cn.youle.pet.shop.pojo.dto.product.ProductSaveDTO;
import cn.youle.pet.shop.pojo.vo.product.ProductDetailVO;
import cn.youle.pet.shop.pojo.vo.product.ProductListVO;
import cn.youle.pet.shop.service.IPetProductService;
import org.apache.shiro.authz.annotation.RequiresAuthentication;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
 * 商品表 前端控制器
 * </p>
 *
 * @author wangrongli
 * @since 2023-09-19
 */
@RestController
@RequestMapping(value = "/api/pet-product",produces = "application/json;charset=UTF-8")
public class PetProductController {

    @Autowired
    private IPetProductService petProductService;

    /**
     * 添加/修改商品
     *
     * @param productSaveDTO 前端输入
     * @return 商品id
     */
    @PostMapping("/create")
    public JsonResponse create(@RequestBody ProductSaveDTO productSaveDTO, HttpServletRequest request) {
        try {
            String id = "";
            if (productSaveDTO.getProductId() == null) {
                id = petProductService.create(productSaveDTO,request);
            } else {
                id = petProductService.update(productSaveDTO,request);
            }
            return JsonResponse.ok(id);
        } catch (Exception e) {
            return JsonResponse.failed(e.getMessage());
        }
    }

    /**
     * 产看商品详情
     *
     * @return 商品详情
     */
    @PostMapping("/detail")
    public JsonResponse detail(@RequestBody ProductDetailDTO productDetailDTO) {
        try {
            ProductDetailVO detail = petProductService.detail(productDetailDTO);
            return JsonResponse.ok(detail);
        } catch (Exception e) {
            return JsonResponse.failed(e.getMessage());
        }
    }

    /**
     * 列表查询
     *
     * @return 商品列表
     */
    @PostMapping("/list")
    public JsonResponse list(@RequestBody ProductListDTO productListDTO) {
        try {
            ProductListVO list = petProductService.list(productListDTO);
            return JsonResponse.ok(list);
        } catch (Exception e) {
            return JsonResponse.failed(e.getMessage());
        }
    }

    /**
     * 删除商品
     *
     * @return 是否删除成功
     */
    @PostMapping("/delete")
    public JsonResponse delete(@RequestBody ProductDetailDTO productDetailDTO) {
        try {
            petProductService.delete(productDetailDTO);
            return JsonResponse.ok();
        } catch (Exception e) {
            return JsonResponse.failed(e.getMessage());
        }
    }

    /**
     * 修改上下架状态
     *
     * @return 是否修改成功
     */
    @PostMapping("/updateStatus")
    public JsonResponse updateStatus(@RequestBody ProductDetailDTO productDetailDTO) {
        try {
            petProductService.updateStatus(productDetailDTO);
            return JsonResponse.ok();
        } catch (Exception e) {
            return JsonResponse.failed(e.getMessage());
        }
    }
}
