package cn.youle.pet.shop.service.impl;

import cn.youle.pet.shop.enums.ENUM_HTTP_CONTENT_TYPE;
import cn.youle.pet.shop.exception.PetShopException;
import cn.youle.pet.shop.pojo.dto.CommonConfigDTO;
import cn.youle.pet.shop.pojo.dto.UploadDTO;
import cn.youle.pet.shop.service.ICommonService;
import com.alibaba.fastjson.JSON;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.io.InputStreamResource;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.UUID;

/**
 * @projectName: pet-shop
 * @description:
 * @author: Administrator
 * @createTime: 2023/9/20 9:07
 */
@Service
@Slf4j
public class CommonServiceImpl implements ICommonService {

    @Resource
    private CommonConfigDTO commonConfigDTO;

    /**
     * 文件上传
     *
     * @param multipartFile
     * @return
     */
    @Override
    public String upload(MultipartFile multipartFile) {
        log.info("****************文件上传开始****************");
        String originalFilename = multipartFile.getOriginalFilename();
        if (originalFilename == null) {
            throw new PetShopException("没有要上传的文件");
        }
        // 获取后缀名
        String suffix = originalFilename.substring(originalFilename.lastIndexOf("."));
        // 重新定义文件名
        UUID uuid = UUID.randomUUID();
        String fileName = uuid.toString();
        fileName = fileName.replace("-", "") + suffix;
        String filePath = commonConfigDTO.getPath();
        filePath = filePath + fileName;
        File file = new File(filePath);
        if (!file.exists()) {
            file.mkdirs();
        }
        try {
            multipartFile.transferTo(file);
            log.info("文件上传成功");
        } catch (Exception e) {
            log.error("文件上传失败,原因是:{}", e.getMessage());
            throw new PetShopException("文件上传失败,原因是:" + e.getMessage());
        }
        log.info("****************文件上传结束****************");
        return filePath;
    }

    /**
     * 下载文件
     *
     * @param filePath
     */
    @Override
    public InputStreamResource download(String filePath) {
        log.info("======================开始获取文件,文件路径:{}======================",filePath);
        // 根据文件名查找对应文件
        File file = new File(filePath);
        if (!file.exists()) {
            throw new PetShopException("该文件不存在");
        }

        FileInputStream fis = null;

        InputStream inputStream = null;
        try {
            // 读取文件流
            inputStream = new FileInputStream(file);
            InputStreamResource inputStreamResource = new InputStreamResource(inputStream);

            log.info("======================文件获取成功,准备返回======================");
            return inputStreamResource;

        } catch (Exception e) {
            log.error("下载接口出现问题,具体原因:{}", e.getMessage());
        } finally {
            try {
                if (fis != null) {
                    fis.close();
                }
            } catch (Exception e) {
                log.error("文件下载错误,原因是:{}", e.getMessage());
                e.printStackTrace();
            }
        }
        return null;
    }
}
