package cn.youle.pet.shop.utils;

import cn.youle.pet.shop.shiro.auth.TokenVO;
import com.alibaba.fastjson.JSON;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.Header;
import io.jsonwebtoken.Jwts;
import io.jsonwebtoken.SignatureAlgorithm;
import lombok.extern.slf4j.Slf4j;

import java.util.Date;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * @projectName: pet-shop
 * @description:
 * @author: Administrator
 * @createTime: 2023/9/11 17:53
 */
@Slf4j
public class JWTUtil {

    /**
     * 设置过期时间60分钟
     */
    private static final long EXPIRE_TIME = 5 * 60 * 60 * 1000;

    /**
     * 校验token是否正确
     *
     * @return
     */
    public static boolean verify(String token, TokenVO tokenVO, String secret) {
        return false;
    }

    private static final String KEY = "pet-shop";

    /**
     * 生成jwt Token
     *
     * @return
     */
    public static String createToken(TokenVO tokenVO) {
        Map<String, Object> claims = new LinkedHashMap<>();
        claims.put("count", tokenVO.getCount());
        claims.put("password", tokenVO.getPassword());
        claims.put("name", tokenVO.getName());
        claims.put("weChatId", tokenVO.getWeChatId());
        claims.put("nickname", tokenVO.getNickname());
        claims.put("code", tokenVO.getCode());
        claims.put("company", tokenVO.getCompany());
        String jwt = Jwts.builder()
                .setHeaderParam(Header.CONTENT_TYPE, "HS256")
                .setHeaderParam(Header.TYPE, Header.JWT_TYPE)
                .setClaims(claims)
                .setExpiration(new Date(System.currentTimeMillis() + 60 * 1000 * 60))
                .signWith(SignatureAlgorithm.HS256, KEY)
                .compact();
        log.info("jwt生成成功:" + jwt);
        return jwt;
    }

    /**
     * 解析token
     *
     * @return
     */
    public static TokenVO parseToken(String jwt) {
        log.info("获取的token数据:{}",jwt);
        TokenVO tokenVO = new TokenVO();
        try {
            Claims body = Jwts.parser().setSigningKey(KEY).parseClaimsJws(jwt).getBody();
            tokenVO.setCount((String) body.get("count"));
            tokenVO.setPassword((String) body.get("password"));
            tokenVO.setName((String) body.get("name"));
            tokenVO.setWeChatId((String) body.get("weChatId"));
            tokenVO.setNickname((String) body.get("nickname"));
            tokenVO.setCode((String) body.get("code"));
            tokenVO.setCompany((String) body.get("company"));
            return tokenVO;
        } catch (Exception e) {
            log.error("解析token出错,原因是:" + e.getMessage());
            return null;
        }
    }

    public static void main(String[] args) {
        String jwt = "eyJjdHkiOiJIUzI1NiIsInR5cCI6IkpXVCIsImFsZyI6IkhTMjU2In0.eyJjb3VudCI6IjAwMSIsInBhc3N3b3JkIjoiMTIzNDU2IiwibmFtZSI6IjAwMSIsIndlQ2hhdElkIjpudWxsLCJleHAiOjE2OTQ2ODYyMzd9.DAjP8mJA7CpVm4FEK98upc_g1LzVXM6gJObgiRTFX7U";
        TokenVO tokenVO = parseToken(jwt);
        System.out.println(JSON.toJSONString(tokenVO));
    }
}
